# API Reference <a name="API Reference"></a>

## Constructs <a name="Constructs"></a>

### EventFunction <a name="mt-awscdk-constructs.EventFunction"></a>

EventFunction.

A Lambda Function, triggered by an EventBridge Event

Includes additional resources:
   - Configurable EventBridge Rule

#### Initializer <a name="mt-awscdk-constructs.EventFunction.Initializer"></a>

```typescript
import { EventFunction } from 'mt-awscdk-constructs'

new EventFunction(scope: Construct, id: string, props: IEventFunctionProps)
```

##### `scope`<sup>Required</sup> <a name="mt-awscdk-constructs.EventFunction.parameter.scope"></a>

- *Type:* [`@aws-cdk/core.Construct`](#@aws-cdk/core.Construct)

---

##### `id`<sup>Required</sup> <a name="mt-awscdk-constructs.EventFunction.parameter.id"></a>

- *Type:* `string`

---

##### `props`<sup>Required</sup> <a name="mt-awscdk-constructs.EventFunction.parameter.props"></a>

- *Type:* [`mt-awscdk-constructs.IEventFunctionProps`](#mt-awscdk-constructs.IEventFunctionProps)

---



#### Properties <a name="Properties"></a>

##### `deliveryDlq`<sup>Required</sup> <a name="mt-awscdk-constructs.EventFunction.property.deliveryDlq"></a>

- *Type:* [`@aws-cdk/aws-sqs.IQueue`](#@aws-cdk/aws-sqs.IQueue)

The SQS Queue which acts as a DLQ for any EventBridge Delivery failures.

---

##### `lambdaFunction`<sup>Required</sup> <a name="mt-awscdk-constructs.EventFunction.property.lambdaFunction"></a>

- *Type:* [`@aws-cdk/aws-lambda.IFunction`](#@aws-cdk/aws-lambda.IFunction)

Lambda Function which is the target of the Event.

---

##### `processingDlq`<sup>Required</sup> <a name="mt-awscdk-constructs.EventFunction.property.processingDlq"></a>

- *Type:* [`@aws-cdk/aws-sqs.IQueue`](#@aws-cdk/aws-sqs.IQueue)

The SQS Queue which acts as a DLQ for any events which the Event Function is unable to process.

---

##### `rule`<sup>Required</sup> <a name="mt-awscdk-constructs.EventFunction.property.rule"></a>

- *Type:* [`@aws-cdk/aws-events.IRule`](#@aws-cdk/aws-events.IRule)

EventBridge Rule which controls when the Event Function is triggered.

---




## Protocols <a name="Protocols"></a>

### IEventFunctionDeliveryProps <a name="mt-awscdk-constructs.IEventFunctionDeliveryProps"></a>

- *Implemented By:* [`mt-awscdk-constructs.IEventFunctionDeliveryProps`](#mt-awscdk-constructs.IEventFunctionDeliveryProps)


#### Properties <a name="Properties"></a>

##### `maxEventAge`<sup>Optional</sup> <a name="mt-awscdk-constructs.IEventFunctionDeliveryProps.property.maxEventAge"></a>

- *Type:* [`@aws-cdk/core.Duration`](#@aws-cdk/core.Duration)

The maximum age of a request that Lambda sends to a function for processing.

---

##### `retryAttempts`<sup>Optional</sup> <a name="mt-awscdk-constructs.IEventFunctionDeliveryProps.property.retryAttempts"></a>

- *Type:* `number`

The maximum number of times to retry when the function returns an error.

---

### IEventFunctionProps <a name="mt-awscdk-constructs.IEventFunctionProps"></a>

- *Implemented By:* [`mt-awscdk-constructs.IEventFunctionProps`](#mt-awscdk-constructs.IEventFunctionProps)


#### Properties <a name="Properties"></a>

##### `functionProps`<sup>Required</sup> <a name="mt-awscdk-constructs.IEventFunctionProps.property.functionProps"></a>

- *Type:* [`@aws-cdk/aws-lambda.FunctionProps`](#@aws-cdk/aws-lambda.FunctionProps)

Configuration of the Event Function Lambda.

---

##### `ruleProps`<sup>Required</sup> <a name="mt-awscdk-constructs.IEventFunctionProps.property.ruleProps"></a>

- *Type:* [`@aws-cdk/aws-events.RuleProps`](#@aws-cdk/aws-events.RuleProps)

The configuration and behaviour of the EventBridge Rule which links the EventBus and the Event Function Lambda.

---

##### `deliveryDlqProps`<sup>Optional</sup> <a name="mt-awscdk-constructs.IEventFunctionProps.property.deliveryDlqProps"></a>

- *Type:* [`@aws-cdk/aws-sqs.QueueProps`](#@aws-cdk/aws-sqs.QueueProps)

Configuration of the Delivery DLQ.

---

##### `deliveryProps`<sup>Optional</sup> <a name="mt-awscdk-constructs.IEventFunctionProps.property.deliveryProps"></a>

- *Type:* [`mt-awscdk-constructs.IEventFunctionDeliveryProps`](#mt-awscdk-constructs.IEventFunctionDeliveryProps)

Configuration of the Delivery properties to the Event Function Lambda.

---

##### `processingDlqProps`<sup>Optional</sup> <a name="mt-awscdk-constructs.IEventFunctionProps.property.processingDlqProps"></a>

- *Type:* [`@aws-cdk/aws-sqs.QueueProps`](#@aws-cdk/aws-sqs.QueueProps)

Configuration of the Processing DLQ.

---

